/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2011. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.rqm.adapter.commandline;

import java.io.File;
import java.io.Serializable;
import java.util.Vector;

/**
 * @author swijenay
 * @author tneal
 *
 * Class to hold information about the execution of an individual JUnit test.
 */
public class JUnitReportEntry implements Serializable {
	private static final long serialVersionUID = 1L;
	private String description;
	private String exceptionTraceback;
	private Vector<File> screenshots;
	private JUnitReportEntryType type;
	private long startTimestamp;
	private long endTimestamp;
	
	public JUnitReportEntry(String message, String exceptionTraceback, Vector<File> screenshots, JUnitReportEntryType type, Long entryStartTime){
		this.description = message;
		this.exceptionTraceback = exceptionTraceback;
		this.screenshots = screenshots;
		this.type = type;
		this.endTimestamp = System.currentTimeMillis();
		this.startTimestamp = entryStartTime != null ? entryStartTime.longValue() : this.endTimestamp;
	}

	public String getDescription() {
		return description;
	}

	public long getStartTimestamp() {
		return startTimestamp;
	}

	public long getEndTimestamp() {
		return endTimestamp;
	}

	public String getExceptionTraceback() {
		return exceptionTraceback;
	}

	/**
	 * @return the screenshots
	 */
	public Vector<File> getScreenshots() {
		return screenshots;
	}

	public JUnitReportEntryType getType() {
		return type;
	}

}
