/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2011. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp. 
 *******************************************************************************/

package com.ibm.rqm.adapter.commandline;

import java.io.File;
import java.io.Serializable;
import java.util.Vector;

/**
 * @author swijenay
 * @author tneal
 * 
 *         Report/store information about the JUnit tests contained within a
 *         single JUnit testcase, including the number of test passes and
 *         failures.
 * 
 */
public class JUnitTestCaseReporter implements Serializable {
	private static final long serialVersionUID = 1L;
	private String testCaseName;
	private Vector<JUnitReportEntry> reportEntries;
	private int noOfReportedFailures;
	private int noOfReportedPasses;
	
	public JUnitTestCaseReporter(String testCaseName){
		this.testCaseName = testCaseName;
		
		this.reportEntries = new Vector<JUnitReportEntry>();
		this.noOfReportedFailures = 0;
		this.noOfReportedPasses = 0;
	}

	public void report(String message, String exceptionTraceback, 
					   Vector<File> screenshots, JUnitReportEntryType type, Long entryStartTime){
		if(type == JUnitReportEntryType.FAIL){
			noOfReportedFailures++;
		}
		else if(type == JUnitReportEntryType.PASS){
			noOfReportedPasses++;
		}
		
		reportEntries.add(new JUnitReportEntry(message, exceptionTraceback, screenshots, type, entryStartTime));
	}

	public String getTestCaseName() {
		return testCaseName;
	}
	
	public Vector<JUnitReportEntry> getReportEntries() {
		return reportEntries;
	}

	public int getNoOfReportedFailures() {
		return noOfReportedFailures;
	}

	public int getNoOfReportedPasses() {
		return noOfReportedPasses;
	}

}
